@@ -414,9 +414,16 @@ def process_self_contained_coordinator_stream(
                 logging.info(
                     "Restoring docker image: {} from {}".format(run_image, airgap_key)
                 )
-                airgap_docker_image_bin = conn.get(airgap_key)
-                images_loaded = docker_client.images.load(airgap_docker_image_bin)
-                logging.info("Successfully loaded images {}".format(images_loaded))
+                if conn.exists(airgap_key):
+                    airgap_docker_image_bin = conn.get(airgap_key)
+                    images_loaded = docker_client.images.load(airgap_docker_image_bin)
+                    logging.info("Successfully loaded images {}".format(images_loaded))
+                else:
+                    logging.error(
+                        "docker image {} was not present on key {}".format(
+                            run_image, airgap_key
+                        )
+                    )
 
             for test_file in testsuite_spec_files:
                 redis_containers = []
@@ -972,6 +979,9 @@ def extract_build_info_from_streamdata(testDetails):
     run_image = build_image
     if b"run_image" in testDetails[b"run_image"]:
         run_image = testDetails[b"run_image"].decode()
+        logging.info("detected run image info {}.".format(run_image))
+    else:
+        logging.info("using build image info {}.".format(build_image))
     if b"build_artifacts" in testDetails:
         build_artifacts_str = testDetails[b"build_artifacts"].decode()
     build_artifacts = build_artifacts_str.split(",")
